ComponentId

Struct ComponentId 

pub struct ComponentId(/* private fields */);
A semi-opaque value which uniquely identifies the type of a Component within a World.

Each time a new Component type is registered within a World using World::init_component or World::init_component_with_descriptor, a corresponding ComponentId is created to track it.

While the distinction between ComponentId and TypeId may seem superficial, breaking them into two separate but related concepts allows components to exist outside of Rust’s type system. Each Rust type registered as a Component will have a corresponding ComponentId, but additional ComponentIds may exist in a World to track components which cannot be represented as Rust types for scripting or other advanced use-cases.

A ComponentId is tightly coupled to its parent World. Attempting to use a ComponentId from one World to access the metadata of a Component in a different World is undefined behaviour and must not be attempted.

Implementations

Source

impl ComponentId

pub const fn new(index: usize) -> ComponentId

pub fn index(self) -> usize