Components

Struct Components 

pub struct Components { /* private fields */ }

Implementations

Source

impl Components

pub fn init_component<T>(&mut self, storages: &mut Storages) -> ComponentId
where T: Component,

pub fn init_component_with_descriptor( &mut self, storages: &mut Storages, descriptor: ComponentDescriptor, ) -> ComponentId

pub fn len(&self) -> usize

pub fn is_empty(&self) -> bool

pub fn get_info(&self, id: ComponentId) -> Option<&ComponentInfo>

pub unsafe fn get_info_unchecked(&self, id: ComponentId) -> &ComponentInfo

Safety

id must be a valid ComponentId

pub fn get_id(&self, type_id: TypeId) -> Option<ComponentId>

Type-erased equivalent of Components::component_id.

pub fn component_id<T>(&self) -> Option<ComponentId>
where T: Component,

Returns the ComponentId of the given Component type T.

The returned ComponentId is specific to the Components instance it was retrieved from and should not be used with another Components instance.

Returns None if the Component type has not yet been initialized using Components::init_component.

use bevy_ecs::prelude::*;

let mut world = World::new();

#[derive(Component)]
struct ComponentA;

let component_a_id = world.init_component::<ComponentA>();

assert_eq!(component_a_id, world.components().component_id::<ComponentA>().unwrap())
pub fn get_resource_id(&self, type_id: TypeId) -> Option<ComponentId>

pub fn init_resource<T>(&mut self) -> ComponentId
where T: Resource,

pub fn init_non_send<T>(&mut self) -> ComponentId
where T: Any,

pub fn iter(&self) -> impl Iterator<Item = &ComponentInfo>