EntityRef

Struct EntityRef 

pub struct EntityRef<'w> { /* private fields */ }
A read-only reference to a particular Entity and all of its components

Implementations

Source

impl<'w> EntityRef<'w>

pub fn id(&self) -> Entity

pub fn location(&self) -> EntityLocation

pub fn archetype(&self) -> &Archetype

pub fn world(&self) -> &'w World

pub fn contains<T>(&self) -> bool
where T: Component,

pub fn contains_id(&self, component_id: ComponentId) -> bool

pub fn contains_type_id(&self, type_id: TypeId) -> bool

pub fn get<T>(&self) -> Option<&'w T>
where T: Component,

pub fn get_change_ticks<T>(&self) -> Option<&'w ComponentTicks>
where T: Component,

Retrieves the change ticks for the given component. This can be useful for implementing change detection in custom runtimes.

pub unsafe fn get_unchecked_mut<T>( &self, last_change_tick: u32, change_tick: u32, ) -> Option<Mut<'w, T>>
where T: Component,

Gets a mutable reference to the component of type T associated with this entity without ensuring there are no other borrows active and without ensuring that the returned reference will stay valid.

Safety
  • The returned reference must never alias a mutable borrow of this component.
  • The returned reference must not be used after this component is moved which may happen from any insert_component, remove_component or despawn operation on this world (non-exhaustive list).
Source

impl<'w> EntityRef<'w>

pub fn get_by_id(&self, component_id: ComponentId) -> Option<Ptr<'w>>

Gets the component of the given ComponentId from the entity.

You should prefer to use the typed API where possible and only use this in cases where the actual component types are not known at compile time.

Unlike EntityRef::get, this returns a raw pointer to the component, which is only valid while the 'w borrow of the lifetime is active.