EventReader

Struct EventReader 

pub struct EventReader<'w, 's, E>
where E: Event,
{ /* private fields */ }
Reads events of type T in order and tracks which events have already been read.

Implementations

Source

impl<'w, 's, E> EventReader<'w, 's, E>
where E: Event,

pub fn iter(&mut self) -> impl DoubleEndedIterator + ExactSizeIterator

Iterates over the events this EventReader has not seen yet. This updates the EventReader’s event counter, which means subsequent event reads will not include events that happened before now.

pub fn iter_with_id(&mut self) -> impl DoubleEndedIterator + ExactSizeIterator

Like iter, except also returning the EventId of the events.

pub fn len(&self) -> usize

Determines the number of events available to be read from this EventReader without consuming any.

pub fn is_empty(&self) -> bool

Determines if no events are available to be read without consuming any. If you need to consume the iterator you can use EventReader::clear.

Example

The following example shows a common pattern of this function in conjunction with clear to avoid leaking events to the next schedule iteration while also checking if it was emitted.

struct CollisionEvent;

fn play_collision_sound(events: EventReader<CollisionEvent>) {
    if !events.is_empty() {
        events.clear();
        // Play a sound
    }
}
pub fn clear(self)

Consumes the iterator.

This means all currently available events will be removed before the next frame. This is useful when multiple events are sent in a single frame and you want to react to one or more events without needing to know how many were sent. In those situations you generally want to consume those events to make sure they don’t appear in the next frame.

For more information see EventReader::is_empty().