pub struct FilteredAccess<T>where
T: SparseSetIndex,{ /* private fields */ }Expand description
An Access that has been filtered to include and exclude certain combinations of elements.
Used internally to statically check if queries are disjoint.
Subtle: a read or write in access should not be considered to imply a
with access.
For example consider Query<Option<&T>> this only has a read of T as doing
otherwise would allow for queries to be considered disjoint when they shouldn’t:
Query<(&mut T, Option<&U>)>read/writeT, readU, withUQuery<&mut T, Without<U>>read/writeT, withoutUfrom this we could reasonably conclude that the queries are disjoint but they aren’t.
In order to solve this the actual access that Query<(&mut T, Option<&U>)> has
is read/write T, read U. It must still have a read U access otherwise the following
queries would be incorrectly considered disjoint:
Query<&mut T>read/writeTQuery<Option<&T>accesses nothing
See comments the WorldQuery impls of AnyOf/Option/Or for more information.
Implementations
Sourceimpl<T> FilteredAccess<T>where
T: SparseSetIndex,
impl<T> FilteredAccess<T>where
T: SparseSetIndex,
Sourcepub fn access_mut(&mut self) -> &mut Access<T>
pub fn access_mut(&mut self) -> &mut Access<T>
Returns a mutable reference to the underlying unfiltered access.
Sourcepub fn add_with(&mut self, index: T)
pub fn add_with(&mut self, index: T)
Retains only combinations where the element given by index is also present.
Sourcepub fn add_without(&mut self, index: T)
pub fn add_without(&mut self, index: T)
Retains only combinations where the element given by index is not present.
pub fn extend_intersect_filter(&mut self, other: &FilteredAccess<T>)
pub fn extend_access(&mut self, other: &FilteredAccess<T>)
Sourcepub fn is_compatible(&self, other: &FilteredAccess<T>) -> bool
pub fn is_compatible(&self, other: &FilteredAccess<T>) -> bool
Returns true if this and other can be active at the same time.
Sourcepub fn get_conflicts(&self, other: &FilteredAccess<T>) -> Vec<T>
pub fn get_conflicts(&self, other: &FilteredAccess<T>) -> Vec<T>
Returns a vector of elements that this and other cannot access at the same time.
Sourcepub fn extend(&mut self, access: &FilteredAccess<T>)
pub fn extend(&mut self, access: &FilteredAccess<T>)
Adds all access and filters from other.