pub type QueryFetch<'w, Q> = <Q as WorldQuery>::Fetch<'w>;Expand description
The Fetch of a WorldQuery, which is used to store state for each archetype/table.
pub type QueryFetch<'w, Q> = <Q as WorldQuery>::Fetch<'w>;The Fetch of a WorldQuery, which is used to store state for each archetype/table.