pub type ROQueryFetch<'w, Q> = <<Q as WorldQuery>::ReadOnly as WorldQuery>::Fetch<'w>;Expand description
The read-only Fetch of a WorldQuery, which is used to store state for each archetype/table.
pub type ROQueryFetch<'w, Q> = <<Q as WorldQuery>::ReadOnly as WorldQuery>::Fetch<'w>;The read-only Fetch of a WorldQuery, which is used to store state for each archetype/table.