SystemDescriptor

Struct SystemDescriptor 

pub struct SystemDescriptor { /* private fields */ }
Encapsulates a system and information on when it run in a SystemStage.

Systems can be inserted into 4 different groups within the stage:

  • Parallel, accepts non-exclusive systems.
  • At start, accepts exclusive systems; runs before parallel systems.
  • Before commands, accepts exclusive systems; runs after parallel systems, but before their command buffers are applied.
  • At end, accepts exclusive systems; runs after parallel systems’ command buffers have been applied.

Systems can have one or more labels attached to them; other systems in the same group can then specify that they have to run before or after systems with that label using the before and after methods.

Example

#[derive(SystemLabel, Debug, Clone, PartialEq, Eq, Hash)]
struct Something;

SystemStage::parallel()
    .with_system(do_something.label(Something))
    .with_system(do_the_other_thing.after(Something))
    .with_system(do_something_else.at_end());