ParallelSystemExecutor

Trait ParallelSystemExecutor 

pub trait ParallelSystemExecutor:
    Downcast
    + Send
    + Sync {
    // Required methods
    fn rebuild_cached_data(&mut self, systems: &[SystemContainer]);
    fn run_systems(
        &mut self,
        systems: &mut [SystemContainer],
        world: &mut World,
    );
}

Required Methods

fn rebuild_cached_data(&mut self, systems: &[SystemContainer])

Called by SystemStage whenever systems have been changed.

fn run_systems(&mut self, systems: &mut [SystemContainer], world: &mut World)

Implementations

Source

impl dyn ParallelSystemExecutor

pub fn is<__T>(&self) -> bool

Returns true if the trait object wraps an object of type __T.

pub fn downcast<__T>( self: Box<dyn ParallelSystemExecutor>, ) -> Result<Box<__T>, Box<dyn ParallelSystemExecutor>>

Returns a boxed object from a boxed trait object if the underlying object is of type __T. Returns the original boxed trait if it isn’t.

pub fn downcast_rc<__T>( self: Rc<dyn ParallelSystemExecutor>, ) -> Result<Rc<__T>, Rc<dyn ParallelSystemExecutor>>

Returns an Rc-ed object from an Rc-ed trait object if the underlying object is of type __T. Returns the original Rc-ed trait if it isn’t.

pub fn downcast_ref<__T>(&self) -> Option<&__T>

Returns a reference to the object within the trait object if it is of type __T, or None if it isn’t.

pub fn downcast_mut<__T>(&mut self) -> Option<&mut __T>

Returns a mutable reference to the object within the trait object if it is of type __T, or None if it isn’t.