Column

Struct Column 

pub struct Column { /* private fields */ }

Implementations

Source

impl Column

pub fn item_layout(&self) -> Layout

pub fn len(&self) -> usize

pub fn is_empty(&self) -> bool

pub fn get_data_ptr(&self) -> Ptr<'_>

pub unsafe fn get_data_slice<T>(&self) -> &[UnsafeCell<T>]

Safety

The type T must be the type of the items in this column.

pub fn get_ticks_slice(&self) -> &[UnsafeCell<ComponentTicks>]

pub fn get(&self, row: usize) -> Option<(Ptr<'_>, &UnsafeCell<ComponentTicks>)>

pub fn get_data(&self, row: usize) -> Option<Ptr<'_>>

pub unsafe fn get_data_unchecked(&self, row: usize) -> Ptr<'_>

Safety
  • index must be in-bounds
  • no other reference to the data of the same row can exist at the same time
pub fn get_data_mut(&mut self, row: usize) -> Option<PtrMut<'_>>

pub fn get_ticks(&self, row: usize) -> Option<&UnsafeCell<ComponentTicks>>

pub unsafe fn get_ticks_unchecked( &self, row: usize, ) -> &UnsafeCell<ComponentTicks>

Safety

index must be in-bounds

pub fn clear(&mut self)