pub struct ResourceData { /* private fields */ }Expand description
The type-erased backing storage and metadata for a single resource within a World.
Implementations
Sourceimpl ResourceData
impl ResourceData
Sourcepub fn is_present(&self) -> bool
pub fn is_present(&self) -> bool
Returns true if the resource is populated.
Sourcepub fn id(&self) -> ArchetypeComponentId
pub fn id(&self) -> ArchetypeComponentId
Gets the ArchetypeComponentId for the resource.
Sourcepub fn get_data(&self) -> Option<Ptr<'_>>
pub fn get_data(&self) -> Option<Ptr<'_>>
Gets a read-only pointer to the underlying resource, if available.
Sourcepub fn get_ticks(&self) -> Option<&ComponentTicks>
pub fn get_ticks(&self) -> Option<&ComponentTicks>
Gets a read-only reference to the change ticks of the underlying resource, if available.