pub struct EntityMap { /* private fields */ }Expand description
A mapping from one set of entities to another.
The API generally follows HashMap, but each Entity is returned by value, as they are Copy.
This is typically used to coordinate data transfer between sets of entities, such as between a scene and the world or over the network.
This is required as Entity identifiers are opaque; you cannot and do not want to reuse identifiers directly.
Implementations
Sourceimpl EntityMap
impl EntityMap
Sourcepub fn insert(&mut self, from: Entity, to: Entity) -> Option<Entity>
pub fn insert(&mut self, from: Entity, to: Entity) -> Option<Entity>
Inserts an entities pair into the map.
If the map did not have from present, None is returned.
If the map did have from present, the value is updated, and the old value is returned.
Sourcepub fn remove(&mut self, entity: Entity) -> Option<Entity>
pub fn remove(&mut self, entity: Entity) -> Option<Entity>
Removes an entity from the map, returning the mapped value of it if the entity was previously in the map.
Sourcepub fn entry(
&mut self,
entity: Entity,
) -> Entry<'_, Entity, Entity, RandomState>
pub fn entry( &mut self, entity: Entity, ) -> Entry<'_, Entity, Entity, RandomState>
Gets the given entity’s corresponding entry in the map for in-place manipulation.
Sourcepub fn get(&self, entity: Entity) -> Result<Entity, MapEntitiesError>
pub fn get(&self, entity: Entity) -> Result<Entity, MapEntitiesError>
Returns the corresponding mapped entity.
Sourcepub fn keys(&self) -> impl Iterator<Item = Entity>
pub fn keys(&self) -> impl Iterator<Item = Entity>
An iterator visiting all keys in arbitrary order.