pub struct Access<T>where
T: SparseSetIndex,{ /* private fields */ }Expand description
Tracks read and write access to specific elements in a collection.
Used internally to ensure soundness during system initialization and execution.
See the is_compatible and get_conflicts functions.
Implementations
Sourceimpl<T> Access<T>where
T: SparseSetIndex,
impl<T> Access<T>where
T: SparseSetIndex,
Sourcepub fn grow(&mut self, capacity: usize)
pub fn grow(&mut self, capacity: usize)
Increases the set capacity to the specified amount.
Does nothing if capacity is less than or equal to the current value.
Sourcepub fn has_read(&self, index: T) -> bool
pub fn has_read(&self, index: T) -> bool
Returns true if this can access the element given by index.
Sourcepub fn has_write(&self, index: T) -> bool
pub fn has_write(&self, index: T) -> bool
Returns true if this can exclusively access the element given by index.
Sourcepub fn has_read_all(&self) -> bool
pub fn has_read_all(&self) -> bool
Returns true if this has access to all indexed elements (i.e. &World).
Sourcepub fn is_compatible(&self, other: &Access<T>) -> bool
pub fn is_compatible(&self, other: &Access<T>) -> bool
Returns true if the access and other can be active at the same time.
Access instances are incompatible if one can write
an element that the other can read or write.
Sourcepub fn get_conflicts(&self, other: &Access<T>) -> Vec<T>
pub fn get_conflicts(&self, other: &Access<T>) -> Vec<T>
Returns a vector of elements that the access and other cannot access at the same time.
Sourcepub fn reads_and_writes(&self) -> impl Iterator<Item = T>
pub fn reads_and_writes(&self) -> impl Iterator<Item = T>
Returns the indices of the elements this has access to.